diff --git a/create_JupyterLab_kernel.sh b/create_JupyterLab_kernel.sh
index 3868d4f7aeefb3a73e10a35f8f0ab1d80be78a64..8c0d02062b46bc176d5cd42ed3f4996505d42b1b 100644
--- a/create_JupyterLab_kernel.sh
+++ b/create_JupyterLab_kernel.sh
@@ -73,3 +73,6 @@ cat <<EOF >$KERNEL_PATH/$KERNEL_NAME/kernel.json
  "env": { "LAB_KERNEL_NAME": "$RELEASE_NAME", "LAB_KERNEL_RELEASE_DATE": "$(date +"%Y-%m-%d")" }
 }
 EOF
+
+# add EBRAINS logo to kernel
+cp $LAB_KERNEL_ROOT/../logo/logo-64x64.png $KERNEL_PATH/$KERNEL_NAME/
diff --git a/install_spack_env.sh b/install_spack_env.sh
index bcb3c8d71a924cf26455aac28de8512d78f23282..e2808820fbd607e7cac7bb0b672f20c292235961 100644
--- a/install_spack_env.sh
+++ b/install_spack_env.sh
@@ -23,12 +23,14 @@ then
   git clone --depth 1 -c advice.detachedHead=false -c feature.manyFiles=true --branch $SPACK_VERSION https://github.com/spack/spack $INSTALLATION_ROOT/spack
   cp $EBRAINS_REPO/packages.yaml $INSTALLATION_ROOT/spack/etc/spack/packages.yaml
   source $INSTALLATION_ROOT/spack/share/spack/setup-env.sh
-  # install platform compiler and python
+  # install platform compiler and python (extract versions from packages.yaml)
+  EBRAINS_SPACK_COMPILER=$(grep 'compiler' $EBRAINS_REPO/packages.yaml | awk -F'[][]' '{ print $2 }')
+  EBRAINS_SPACK_PYTHON=python@$(grep -A1 'python' $EBRAINS_REPO/packages.yaml | tail -n1 | awk -F'[][]' '{ print $2 }')
   spack compiler find
-  spack install gcc@10.3.0
-  spack load gcc@10.3.0
+  spack install $EBRAINS_SPACK_COMPILER
+  spack load $EBRAINS_SPACK_COMPILER
   spack compiler find
-  spack install python@3.8.11 %gcc@10.3.0
+  spack install $EBRAINS_SPACK_PYTHON %$EBRAINS_SPACK_COMPILER
 else
   source $INSTALLATION_ROOT/spack/share/spack/setup-env.sh
 fi